==> netbeans_6.9.orig.tar.gz: netbeans-6.9/projectimport.eclipse.core/src/org/netbeans/modules/projectimport/eclipse/core/UpdateProjectAction.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.projectimport.eclipse.core;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.netbeans.api.project.Project;
import org.netbeans.modules.projectimport.eclipse.core.spi.UpgradableProjectLookupProvider;
import org.openide.awt.DynamicMenuContent;
import org.openide.util.ContextAwareAction;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

public final class UpdateProjectAction extends AbstractAction implements ContextAwareAction {
    
    private Lookup context;
    
    public UpdateProjectAction() {
        this(null);
    }

    public UpdateProjectAction(Lookup actionContext) {
        super(NbBundle.getMessage(UpdateProjectAction.class, "UpdateProjectAction.Name"));
        this.context = actionContext;
        putValue(DynamicMenuContent.HIDE_WHEN_DISABLED, true);
    }

    public @Override void actionPerformed(ActionEvent ignore) {
        new UpdateAllProjects().update(false);
    }

    @Override
    public boolean isEnabled() {
        assert context != null;
        Project p = context.lookup(Project.class);
        if (p == null || !UpgradableProjectLookupProvider.isRegistered(p)) {
            return false;
        }
        UpgradableProject upgradable = p.getLookup().lookup(UpgradableProject.class);
        return upgradable != null && upgradable.isUpgradable();
    }
    
    public @Override Action createContextAwareInstance(Lookup actionContext) {
        return new UpdateProjectAction(actionContext);
    }

}

==> netbeans_7.0.1+dfsg1.orig.tar.gz: netbeans-7.0.1+dfsg1/projectimport.eclipse.core/src/org/netbeans/modules/projectimport/eclipse/core/UpdateProjectAction.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.projectimport.eclipse.core;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.netbeans.api.project.Project;
import org.netbeans.modules.projectimport.eclipse.core.spi.UpgradableProjectLookupProvider;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionRegistration;
import org.openide.awt.DynamicMenuContent;
import org.openide.util.ContextAwareAction;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

@ActionID(id = "org.netbeans.modules.projectimport.eclipse.core.UpdateProjectAction", category = "Project")
@ActionRegistration(displayName = "#UpdateProjectAction.Name")
@ActionReference(position = 234, path = "Projects/Actions")
public final class UpdateProjectAction extends AbstractAction implements ContextAwareAction {
    
    private Lookup context;
    
    public UpdateProjectAction() {
        this(null);
    }

    public UpdateProjectAction(Lookup actionContext) {
        super(NbBundle.getMessage(UpdateProjectAction.class, "UpdateProjectAction.Name"));
        this.context = actionContext;
        putValue(DynamicMenuContent.HIDE_WHEN_DISABLED, true);
    }

    public @Override void actionPerformed(ActionEvent ignore) {
        new UpdateAllProjects().update(false);
    }

    @Override
    public boolean isEnabled() {
        assert context != null;
        Project p = context.lookup(Project.class);
        if (p == null || !UpgradableProjectLookupProvider.isRegistered(p)) {
            return false;
        }
        UpgradableProject upgradable = p.getLookup().lookup(UpgradableProject.class);
        return upgradable != null && upgradable.isUpgradable();
    }
    
    public @Override Action createContextAwareInstance(Lookup actionContext) {
        return new UpdateProjectAction(actionContext);
    }

}
